﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace PropertyGrid.Controls
{
    /// <summary>
    /// Logique d'interaction pour DateTimePanel.xaml
    /// </summary>
    public partial class DateTimePanel : UserControl
    {
        #region Fields

        Label mCurrentSelection = null;

        #endregion

        #region Properties

        public DateTime Value
        {
            get;
            set;
        }

        #endregion // Properties.

        #region Methods

        /// <summary>
        /// Default constructor.
        /// </summary>
        public DateTimePanel()
        {
            InitializeComponent();
            Value = DateTime.Now;
            UpdatePanels();
        }

        void UpdatePanels()
        {
            mLCurrentDate.Content = Value.Date.ToLongDateString();
            UpdateDates();
            UpdateSelection();
        }

        void UpdateDates()
        {
            // 1) Compute the first day of the month.
            DayOfWeek lFirstDay = DateTimeHelpers.GetFirstDayOfMonth(Value);
            Int32 lFirstDayColIdx = (Int32)(lFirstDay);
            DateTime lDate = Value.AddDays(-Value.Day + 1.0);
            lDate = lDate.AddDays(-lFirstDayColIdx);

            // 2) Iterate on each labels.
            for
                (Int32 lRowIdx = 0; lRowIdx < 6; lRowIdx++)
            {
                for
                    (Int32 lColIdx = 0; lColIdx < 7; lColIdx++)
                {
                    String lLabelName = "mL" + lRowIdx + "" + lColIdx;
                    Label lNestedLabel = mGDates.FindName(lLabelName) as Label;
                    if
                        (lNestedLabel != null)
                    {
                        lNestedLabel.Content = lDate.Day;

                        if
                            (lDate.Month != Value.Month)
                        {
                            lNestedLabel.IsEnabled = false;
                        }
                        else
                        {
                            lNestedLabel.IsEnabled = true;
                        }
                    }
                    

                    lDate = lDate.AddDays(1.0);
                }
            }
        }

        private void UpdateSelection()
        {
            // Unhightlight previous one.
            if
                (mCurrentSelection != null)
            {
                mCurrentSelection.BorderThickness = new System.Windows.Thickness(0.0);
                mCurrentSelection.FontWeight = System.Windows.FontWeights.Regular;
            }

            // Hightlight new one.
            for
                (Int32 lRowIdx = 0; lRowIdx < 6; lRowIdx++)
            {
                for
                    (Int32 lColIdx = 0; lColIdx < 7; lColIdx++)
                {
                    String lLabelName = "mL" + lRowIdx + "" + lColIdx;
                    Label lNestedLabel = mGDates.FindName(lLabelName) as Label;
                    if
                        (lNestedLabel != null)
                    {
                        if
                            (lNestedLabel.IsEnabled)
                        {
                            Int32 lDayInLabel = (Int32)(lNestedLabel.Content);
                            if
                                (lDayInLabel == Value.Day)
                            {
                                mCurrentSelection = lNestedLabel;
                                mCurrentSelection.BorderThickness = new System.Windows.Thickness(1.0);
                                mCurrentSelection.BorderBrush = new SolidColorBrush(Colors.DimGray);
                                mCurrentSelection.FontWeight = System.Windows.FontWeights.SemiBold;
                            }
                        }
                    }
                }
            }


        }

        private void OnNumberClicked(Object pSender, MouseButtonEventArgs pEvent)
        {
            Label lLabelClicked = pSender as Label;
            if
                (lLabelClicked != null)
            {
                Int32 lDayToSet = (Int32)lLabelClicked.Content;
                Int32 lDiff = lDayToSet - this.Value.Day;
                this.Value = Value.AddDays(lDiff);
                this.UpdatePanels();

            }
            
        }

        private void OnLeftClicked(object sender, MouseButtonEventArgs e)
        {
            Value = Value.AddMonths(-1);
            UpdatePanels();
        }

        private void OnRightClicked(object sender, MouseButtonEventArgs e)
        {
            Value = Value.AddMonths(1);
            UpdatePanels();
        }

        private void OnNumberMouseEnter(object pSender, MouseEventArgs e)
        {
            Label lLabelHovered = pSender as Label;
            if
                (   (lLabelHovered != null)
                &&  (lLabelHovered != mCurrentSelection)
                )
            {
                lLabelHovered.FontWeight = System.Windows.FontWeights.Bold;
            }
        }

        private void OnNumberMouseLeave(object pSender, MouseEventArgs e)
        {
            Label lLabelHovered = pSender as Label;
            if
                (   (lLabelHovered != null)
                &&  (lLabelHovered != mCurrentSelection)
                )
            {
                lLabelHovered.FontWeight = System.Windows.FontWeights.Regular;
            }
        }

        #endregion
    }
}
