﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Data;
using System.Windows.Media;

namespace PropertyGridEditors.Converters
{
    /// <summary>
    /// This converter allows to convert from Brush to Color type.
    /// </summary>
    /// <!-- NBY -->
    [ValueConversion(typeof(Brush), typeof(Color))]
    public class BrushToColorConverter : IValueConverter
    {
        #region Methods

        /// <summary>
        /// Convert from Color to Brush.
        /// </summary>
        /// <param name="value">The value to convert.</param>
        /// <param name="pTargetType">The target type.</param>
        /// <param name="pExtraParameter">The extra parameter to use (not used by the converter).</param>
        /// <param name="pCulture">The culture to use (not used by the converter).</param>
        /// <returns>The value converted.</returns>
        public Object ConvertBack(Object pValue, Type pTargetType, Object pExtraParameter, System.Globalization.CultureInfo pCulture)
        {
            if
                (pValue == null)
            {
                return Binding.DoNothing;
            }

            Color lColor = (Color)pValue;
            return new SolidColorBrush(lColor);
        }

        /// <summary>
        /// Convert from Brush to Color.
        /// </summary>
        /// <param name="value">The value to convert.</param>
        /// <param name="pTargetType">The target type.</param>
        /// <param name="pExtraParameter">The extra parameter to use (not used by the converter).</param>
        /// <param name="pCulture">The culture to use (not used by the converter).</param>
        /// <returns>The value converted.</returns>
        public Object Convert(Object pValue, Type pTargetType, Object pExtraParameter, System.Globalization.CultureInfo pCulture)
        {
            SolidColorBrush lSolidBrush = pValue as SolidColorBrush;

            if
                (lSolidBrush == null)
            {
                return Binding.DoNothing;
            }

            return lSolidBrush.Color;
        }

        #endregion // Methods.
    }
}
