﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Data;
using System.Windows.Media;

namespace PropertyGridEditors.Converters
{
    /// <summary>
    /// This converter allows to convert from a numeric value to a String type.
    /// </summary>
    /// <!-- DPE -->
    [ValueConversion(typeof(Object), typeof(String))]
    public class ToStringConverter : IValueConverter
    {
        #region Fields

        /// <summary>
        /// The owned numeric type.
        /// </summary>
        private Type mOwnedType;

        #endregion // Fields.

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the ToStringConverter class.
        /// </summary>
        public ToStringConverter()
        {
            StringFormat = String.Empty;
        }

        #endregion // Constructors.

        #region Properties

        /// <summary>
        /// The format of the value displayed.
        /// </summary>
        public String StringFormat { get; set; }

        #endregion // Properties.

        #region Methods

        /// <summary>
        /// Convert from Numeric value to String.
        /// </summary>
        /// <param name="value">The value to convert.</param>
        /// <param name="pTargetType">The target type.</param>
        /// <param name="pExtraParameter">The extra parameter to use (not used by the converter).</param>
        /// <param name="pCulture">The culture to use (not used by the converter).</param>
        /// <returns>The value converted.</returns>
        public Object Convert(Object pValue, Type pTargetType, Object pExtraParameter, System.Globalization.CultureInfo pCulture)
        {
            if
                (pValue == null)
            {
                return Binding.DoNothing;
            }

            /**
             * Converters are commonly given to a textbox Text binding.
             * In this case, this method is called first, and the value 
             * type can be saved to be used in the ConvertBackMethod.
             */
            mOwnedType = pValue.GetType();

            // Applying the format if any.
            if
                (StringFormat == String.Empty)
            {
                return pValue.ToString();
            }
            else
            {
                return String.Format(StringFormat, pValue);
            }
        }

        /// <summary>
        /// Convert from String to Numeric value.
        /// </summary>
        /// <param name="value">The value to convert.</param>
        /// <param name="pTargetType">The target type.</param>
        /// <param name="pExtraParameter">The extra parameter to use (not used by the converter).</param>
        /// <param name="pCulture">The culture to use (not used by the converter).</param>
        /// <returns>The value converted.</returns>
        public Object ConvertBack(Object pValue, Type pTargetType, Object pExtraParameter, System.Globalization.CultureInfo pCulture)
        {
            try
            {
                Object lNumericValue = System.Convert.ChangeType(pValue, mOwnedType, pCulture);
                return lNumericValue;
            }
            catch
                (Exception /*pException*/)
            {
                return Binding.DoNothing;
            }
        }

        #endregion // Methods.
    }
}
