﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using WPFColorPickerLib;

namespace PropertyGridEditors.Editors
{
    /// <summary>
    /// Logique d'interaction pour ColorSelector.xaml
    /// </summary>
    public partial class ColorSelector : UserControl
    {
        #region Dependencies

        public static readonly DependencyProperty SelectedColorProperty = DependencyProperty.Register("SelectedColor", typeof(Brush), typeof(ColorSelector), new PropertyMetadata(new SolidColorBrush(Colors.Black), new PropertyChangedCallback(OnSelectedColorChanged)));

        #endregion // Dependencies.

        #region Properties

        /// <summary>
        /// Gets or sets the selected color as brush.
        /// </summary>
        public Brush SelectedColor
        {
            get
            {
                return (Brush)GetValue(SelectedColorProperty);
            }
            set
            {
                SetValue(SelectedColorProperty, value);
                this.mPickColor.Background = SelectedColor;
            }
        }

        #endregion // Properties.

        #region Methods

        /// <summary>
        /// Defautl constructor.
        /// </summary>
        public ColorSelector()
        {
            InitializeComponent();
        }

        /// <summary>
        /// This method is called when the "PickColorButton" is clicked.
        /// </summary>
        /// <param name="pSender">The event sender.</param>
        /// <param name="pEventArgs">The event arguments.</param>
        private void OnPickColorButtonClicked(Object pSender, RoutedEventArgs pEventArgs)
        {
            ColorDialog lColorDialog = new ColorDialog();
            if
                ((bool)lColorDialog.ShowDialog())
            {
                SelectedColor = new SolidColorBrush(lColorDialog.SelectedColor);
            }
        }

        /// <summary>
        /// This method is called when dependency object is modified.
        /// </summary>
        /// <param name="pObject">The dependency object.</param>
        /// <param name="pEventArgs">The event arguments.</param>
        private static void OnSelectedColorChanged(DependencyObject pObject, DependencyPropertyChangedEventArgs pEventArgs)
        {
            if
                (pObject is ColorSelector)
            {
                ColorSelector lColorSelector = pObject as ColorSelector;
                lColorSelector.SelectedColor = (Brush) (pEventArgs.NewValue);
            }

        }

        #endregion
    }
}
