﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Windows.Controls.Primitives;

namespace PropertyGridEditors.Editors.Components
{
    /// <summary>
    /// Describes a button specialy styled for the NumericUpDown.
    /// </summary>
    /// <!-- DPE -->
    public class ButtonUpDown : RepeatButton
    {
        #region Dependency properties

        /// <summary>
        /// The dependency property which owned the ButtonStyle property.
        /// </summary>
        public static readonly DependencyProperty ButtonStyleProperty = DependencyProperty.Register("ButtonStyle",
                typeof(ButtonStyleType), typeof(ButtonUpDown),
                new PropertyMetadata(ButtonStyleType.eDown, new PropertyChangedCallback(OnStyleChanged)));

        #endregion // Dependency properties.

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the ButtonUpDown class.
        /// </summary>
        public ButtonUpDown()
        {
        }

        #endregion // Constructors.

        #region Properties

        /// <summary>
        /// Defines the button style.
        /// </summary>
        public ButtonStyleType ButtonStyle
        {
            get
            {
                return (ButtonStyleType)GetValue(ButtonStyleProperty);
            }
            set
            {
                SetValue(ButtonStyleProperty, value);
            }
        }

        #endregion // Properties.

        #region Methods

        /// <summary>
        /// This method is called when dependency object is modified.
        /// </summary>
        /// <param name="pObject">The dependency object.</param>
        /// <param name="pEventArgs">The event arguments.</param>
        private static void OnStyleChanged(DependencyObject pObject, DependencyPropertyChangedEventArgs pEventArgs)
        {
            if
                (pObject is ButtonUpDown)
            {
                ButtonUpDown lButtonUpDown = pObject as ButtonUpDown;
                lButtonUpDown.ButtonStyle = (ButtonStyleType)(pEventArgs.NewValue);
            }
        }

        #endregion // Methods.

        #region Inner structure

        /// <summary>
        /// Defines the button style, that is to say the arrow orientation.
        /// </summary>
        public enum ButtonStyleType
        {
            /// <summary>
            /// The arrow is up.
            /// </summary>
            eUp,

            /// <summary>
            /// The arrow is down.
            /// </summary>
            eDown
        }

        #endregion // Inner structure.
    }
}
