﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;
using PropertyGridLib;

namespace PropertyGridEditors.ViewModels
{
    /// <summary>
    /// This class describes a number view model for a property which hosts a number.
    /// </summary>
    /// <!-- DPE -->
    public class NumericPropertyViewModel : PropertyViewModel
    {
        #region Methods

        /// <summary>
        /// Initializes a new instance of the NumericPropertyViewModel class.
        /// </summary>
        /// <param name="pInstance">The instance to introspect.</param>
        /// <param name="pPropertyDescriptor">The property descriptor.</param>
        public NumericPropertyViewModel(Object pInstance, PropertyDescriptor pPropertyDescriptor)
        :base(pInstance, pPropertyDescriptor)
        {
        }

        #endregion // Methods.

        #region Properties

        /// <summary>
        /// Gets the maximum value of the possible value range.
        /// </summary>
        public Object MaxValue
        {
            get
            {
                if
                    (PropertyType == typeof(System.Int32))
                {
                    return 100;
                }
                else if
                    (PropertyType == typeof(System.Single))
                {
                    return 100.0f;
                }
                else if
                    (PropertyType == typeof(System.Double))
                {
                    return 100.0;
                }

                return null;
            }
        }

        /// <summary>
        /// Gets the minimum value of the possible value range.
        /// </summary>
        public Object MinValue
        {
            get
            {
                if
                    (PropertyType == typeof(System.Int32))
                {
                    return -100;
                }
                else if
                    (PropertyType == typeof(System.Single))
                {
                    return -100.0f;
                }
                else if
                    (PropertyType == typeof(System.Double))
                {
                    return -100.0;
                }

                return null;
            }
        }

        /// <summary>
        /// Gets the step used to increment or decrement the current value.
        /// </summary>
        public Object StepValue
        {
            get
            {
                if
                    (PropertyType == typeof(System.Int32))
                {
                    return 1;
                }
                else if
                    (PropertyType == typeof(System.Single))
                {
                    return .1f;
                }
                else if
                    (PropertyType == typeof(System.Double))
                {
                    return .01;
                }

                return null;
            }
        }

        /// <summary>
        /// Gets the format used to display the current value.
        /// </summary>
        public Int32 Precision
        {
            get
            {
                if
                    (PropertyType == typeof(System.Single))
                {
                    return 1;
                }
                else if
                    (PropertyType == typeof(System.Double))
                {
                    return 2;
                }

                return 0;
            }
        }

        #endregion // Properties.
    }
}
