﻿using System.Collections.Generic;
using System.Linq;
using System.Windows;
using System;

namespace PropertyGridLib
{
    /// <summary>
    /// This class defines the view model for categories.
    /// </summary>
    /// <!-- NBY -->
    public class CategoryViewModel : PropertyViewModelBase
    {
        #region Fields

        /// <summary>
        /// Field which store the activeness of the view model.
        /// </summary>
        private bool mIsEnabled = true;

        #endregion // Fields.

        #region Properties

        /// <summary>
        /// This property is used to expose the list of inner properties.
        /// </summary>
        public List<PropertyViewModel> Properties 
        { 
            get; 
            private set; 
        }

        /// <summary>
        /// This property is used to expose the name of the view model.
        /// </summary>
        public String Name 
        { 
            get; 
            set; 
        }

        /// <summary>
        /// This property is used to expose the activness of the view model.
        /// </summary>
        public bool IsEnabled
        {
            get 
            {
                return mIsEnabled; 
            }
            set
            {
                mIsEnabled = value;
                NotifyPropertyChanged("IsEnabled");
            }
        }

        /// <summary>
        /// This property is used to expose the header visibility.
        /// </summary>
        public Visibility Visibility
        {
            get 
            { 
                return Visibility.Visible; 
            }
        }

        #endregion // Properties.

        #region Methods

        /// <summary>
        /// Default constrictor.
        /// </summary>
        /// <param name="pCategoryName">The category name.</param>
        /// <param name="pOwner">The onwer of the view model (PropertyEditor).</param>
        public CategoryViewModel(String pCategoryName)
        :base()
        {
            Name = pCategoryName;
            DisplayString = pCategoryName;
            Properties = new List<PropertyViewModel>();
        }

        #endregion
    }
}