﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace PropertyGridLib
{
    /// <summary>
    /// This class implements the property control.
    /// </summary>
    /// <!-- NBY -->
    public partial class PropertyControl : UserControl
    {
        #region Fields

        /// <summary>
        /// This field stores the content control to generate the property editor.
        /// </summary>
        private ContentControl mContentControl = null;

        /// <summary>
        /// This field stores the model.
        /// </summary>
        private List<PropertyViewModel> mModel = null;

        #endregion

        #region Properties

        /// <summary>
        /// Gets or set the label with for all templates.
        /// </summary>
        public Double LabelWidth
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or set the selected object.
        /// </summary>
        public Object SelectedObject
        {
            get;
            set;
        }

        #endregion // Properties

        #region Methods

        /// <summary>
        /// Default constructor.
        /// </summary>
        public PropertyControl()
        {
            InitializeComponent();
            this.Loaded += new RoutedEventHandler(OnControlLoaded);
            LabelWidth = 100;
        }

        /// <summary>
        /// This delegate is called when the control is loaded.
        /// </summary>
        /// <param name="pSender">The event sender.</param>
        /// <param name="pEventArgs">The event arguments.</param>
        void OnControlLoaded(Object pSender, RoutedEventArgs pEventArgs)
        {
            UpdateContent();
        }

        /// <summary>
        /// Updates the content of the control
        /// </summary>
        public void UpdateContent()
        {
            if (!IsLoaded)
            {
                return;
            }

            if
                (mContentControl == null)
            {
                mContentControl = this.FindName("PART_PAGE") as ContentControl;
            }

            // Unreference the model.
            mModel = null;

            // Create simple view models.
            mModel = PropertyViewModelFactory.Instance.CreateViewModel(SelectedObject);
            if
                (mModel != null)
            {
                CategoryViewModel lCategoryModel = new CategoryViewModel("General");
                foreach
                    (PropertyViewModel lSimpleViewModel in mModel)
                {
                    lCategoryModel.Properties.Add(lSimpleViewModel);
                }

                try
                {
                    mContentControl.Content = lCategoryModel;
                }
                catch
                    (Exception lEx)
                {
                    Console.WriteLine("UpdateContent() : " + lEx.ToString());
                }
            }
        }

        #endregion
    }
}
