﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Media;
using System.ComponentModel;

namespace PropertyGridSample
{
    /// <summary>
    /// This class is used to test the property control
    /// </summary>
    /// <!-- NBY -->
    public class MyExampleObjetWithoutAttribute : INotifyPropertyChanged
    {
        #region Fields

        /// <summary>
        /// This field stores a double value.
        /// </summary>
        private Double mDoubleValue;

        /// <summary>
        /// This field stores a integer value.
        /// </summary>
        private Int32 mIntValue;

        /// <summary>
        /// This field stores a string value.
        /// </summary>
        private String mStrValue;

        /// <summary>
        /// The field stores a float value.
        /// </summary>
        private Single mFloatValue;

        /// <summary>
        /// This field stores a boolean value.
        /// </summary>
        private Boolean mBoolValue;

        /// <summary>
        /// This field stores a color value.
        /// </summary>
        private Color mColorValue;

        /// <summary>
        /// This field stores a date/time value.
        /// </summary>
        private DateTime mDateTimeValue;

        #endregion

        #region Events

        /// <summary>
        /// This event is called each time a property is changed.
        /// </summary>
        public event PropertyChangedEventHandler PropertyChanged = null;

        #endregion

        #region Methods
        
        /// <summary>
        /// Default constructor.
        /// </summary>
        public MyExampleObjetWithoutAttribute()
        {
        }

        /// <summary>
        /// This method raises an event when a property is changed./
        /// </summary>
        /// <param name="pPropertyName">The property name which has changed.</param>
        void RaisePropertyChanged(String pPropertyName)
        {
            if
                (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(pPropertyName));
            }
        }

        #endregion

        #region Properties

        /// <summary>
        /// Gets or sets the double value.
        /// </summary>
        public Double DoubleValue
        {
            get
            {
                return mDoubleValue;
            }
            set
            {
                mDoubleValue = value;
                this.RaisePropertyChanged("DoubleValue");
            }
        }

        /// <summary>
        /// Gets or sets the integer value.
        /// </summary>
        public Int32 IntValue
        {
            get
            {
                return mIntValue;
            }
            set
            {
                mIntValue = value;
                this.RaisePropertyChanged("IntValue");
            }
        }

        /// <summary>
        /// Gets or sets the float value.
        /// </summary>
        public Single FloatValue
        {
            get
            {
                return mFloatValue;
            }
            set
            {
                mFloatValue = value;
                this.RaisePropertyChanged("FloatValue");
            }
        }

        /// <summary>
        /// Gets or sets the string value.
        /// </summary>
        public String StrValue
        {
            get
            {
                return mStrValue;
            }
            set
            {
                mStrValue = value;
                this.RaisePropertyChanged("StrValue");
            }
        }

        /// <summary>
        /// Gets or sets the boolean value.
        /// </summary>
        public Boolean BoolValue
        {
            get
            {
                return mBoolValue;
            }
            set
            {
                mBoolValue = value;
                this.RaisePropertyChanged("BoolValue");
            }
        }

        /// <summary>
        /// Gets or sets the color value.
        /// </summary>
        public Color ColorValue
        {
            get
            {
                return mColorValue;
            }
            set
            {
                mColorValue = value;
                this.RaisePropertyChanged("ColorValue");
            }
        }

        /// <summary>
        /// Gets or sets the date/time value.
        /// </summary>
        public DateTime DateTimeValue
        {
            get
            {
                return mDateTimeValue;
            }
            set
            {
                mDateTimeValue = value;
                this.RaisePropertyChanged("DateTimeValue");
            }
        }

        #endregion 
    }
}
